==> spring-cloud-contract-shade-3.1.3-sources.jar: shaded/org/apache/maven/settings/building/DefaultSettingsBuildingResult.java <==
package shaded.shaded.org.apache.maven.settings.building;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.util.ArrayList;
import java.util.List;

import shaded.shaded.org.apache.maven.settings.Settings;

/**
 * Collects the output of the settings builder.
 *
 * @author Benjamin Bentmann
 */
class DefaultSettingsBuildingResult
    implements SettingsBuildingResult
{

    private Settings effectiveSettings;

    private List<SettingsProblem> problems;

    DefaultSettingsBuildingResult( Settings effectiveSettings, List<SettingsProblem> problems )
    {
        this.effectiveSettings = effectiveSettings;
        this.problems = ( problems != null ) ? problems : new ArrayList<SettingsProblem>();
    }

    @Override
    public Settings getEffectiveSettings()
    {
        return effectiveSettings;
    }

    @Override
    public List<SettingsProblem> getProblems()
    {
        return problems;
    }

}

==> spring-cloud-contract-shade-4.1.4-sources.jar: shaded/org/apache/maven/settings/building/DefaultSettingsBuildingResult.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package shaded.shaded.org.apache.maven.settings.building;

import java.util.ArrayList;
import java.util.List;

import shaded.shaded.org.apache.maven.settings.Settings;

/**
 * Collects the output of the settings builder.
 *
 * @author Benjamin Bentmann
 */
class DefaultSettingsBuildingResult implements SettingsBuildingResult {

    private Settings effectiveSettings;

    private List<SettingsProblem> problems;

    DefaultSettingsBuildingResult(Settings effectiveSettings, List<SettingsProblem> problems) {
        this.effectiveSettings = effectiveSettings;
        this.problems = (problems != null) ? problems : new ArrayList<SettingsProblem>();
    }

    @Override
    public Settings getEffectiveSettings() {
        return effectiveSettings;
    }

    @Override
    public List<SettingsProblem> getProblems() {
        return problems;
    }
}
